Load and combine data
load_loggernet_flux_data.RdThis file takes in a list of file paths and loads/formats the data for analysis. The formatting done here is specific to the loggernet file formats for the GENX and Chapada projects.
load_loggernet_flux_data.RdThis file takes in a list of file paths and loads/formats the data for analysis. The formatting done here is specific to the loggernet file formats for the GENX and Chapada projects.